@@ -1,4 +1,4 @@
-# $Id: ldiff.pl 28861 2009-09-24 15:52:07Z wsl $
+# $Id: ldiff.pl 28910 2009-09-30 12:21:01Z wsl $
 # $URL: https://infix.uvt.nl/its-id/trunk/sources/ldiff/script/ldiff.pl $
 
 =encoding utf8
@@ -237,9 +237,9 @@ sub readldif {
 				keys %h = 10;
 				$record = \%h;
 			}
-		} elsif(ord($line) == 32) {
+		} elsif(ord($line) == 32) { # space
 			$entry .= substr($line, 1);
-		} else {
+		} elsif(ord($line) != 35) { # hash
 			if($entry ne '') {
 				if(defined $dn) {
 					my ($key, $val) = canonical_entry $entry;
